@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef RENAMESCRIPTJOB_H
-#define RENAMESCRIPTJOB_H
+#pragma once
 
 #include "ksieveui_export.h"
 #include <QObject>
@@ -51,4 +50,3 @@ private:
     std::unique_ptr<RenameScriptJobPrivate> const d;
 };
 }
-#endif // RENAMESCRIPTJOB_H
