@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,9 +16,7 @@ LineEditValidator::LineEditValidator(QWidget *parent)
     initialize();
 }
 
-LineEditValidator::~LineEditValidator()
-{
-}
+LineEditValidator::~LineEditValidator() = default;
 
 void LineEditValidator::initialize()
 {
